## START: Set by rpmautospec
## (rpmautospec version 0.8.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%bcond tests 1

%global commit 0c4a22b64b23dfad27387750cf07487efc45eb05
%global snapdate 20250615

Name:           python-pydantic
Version:        2.11.7^%{snapdate}git%{sub %{commit} 1 7}
%global srcversion %{lua:return(rpm.expand("%{version}"):gsub("~",""))}
Release:        %autorelease
Summary:        Data validation using Python type hinting

# SPDX
License:        MIT
URL:            https://github.com/pydantic/pydantic
%dnl Source:         %{url}/archive/v%{srcversion}/pydantic-%{srcversion}.tar.gz
Source:         %{url}/archive/%{commit}/pydantic-%{commit}.tar.gz

# Add initial support for Python 3.14
# https://github.com/pydantic/pydantic/pull/11991
Patch:          %{url}/pull/11991.patch

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  tomcli
# For check phase
%if %{with tests}
# We could generate test dependencies using dependency groups, but there are so
# many unwanted dependencies that it is easier to list them manually.

# From the dev dependency group:
# coverage[toml] is for coverage analysis, therefore unwanted downstream
BuildRequires:  %{py3_dist pytz}
BuildRequires:  %{py3_dist dirty-equals}
# eval-type-backport is only needed for older Pythons
BuildRequires:  %{py3_dist pytest}
BuildRequires:  %{py3_dist pytest-mock}
# pytest-pretty is purely cosmetic
# pytest-examples is not packaged (and not mandatory)
# faker is only used in a benchmark, which we do not run
# pytest-benchmark is only for benchmarking
# pytest-codspeed is only for benchmarking
# pytest-run-parallel might be useful, but is not packaged
BuildRequires:  %{py3_dist packaging}
BuildRequires:  %{py3_dist jsonschema}

# From the testing-extra dependency group:
BuildRequires:  %{py3_dist cloudpickle}
# devtools is not packaged; ansi2html is used only with devtools
# sqlalchemy is "used in docs tests" that we do not run
# pytest-memray is a profiler, therefore unwanted downstream
%endif

%global _description %{expand:
Data validation and settings management using python type hinting.}

%description %{_description}


%package -n     python3-pydantic
Summary:        %{summary}
Recommends:     python3-pydantic+email

%description -n python3-pydantic %{_description}


%package        doc
Summary:        Documentation for Pydantic

%description    doc
This package includes the documentation for Pydantic in Markdown format.


%prep
%dnl %autosetup -n pydantic-%{srcversion} -p1
%autosetup -n pydantic-%{commit} -p1

# Delete pytest addopts. We don't care about benchmarking or coverage.
tomcli-set pyproject.toml del 'tool.pytest.ini_options.addopts'
# Work around patched-out pytest-run-parallel plugin dependency (avoid
# "pytest.PytestUnknownMarkWarning: Unknown pytest.mark.thread_unsafe" error)
tomcli-set pyproject.toml append 'tool.pytest.ini_options.markers' \
    'thread_unsafe: mark as incompatible with patched-out pytest-run-parallel'


%generate_buildrequires
%pyproject_buildrequires -x email -x timezone


%build
%pyproject_wheel


# Docs are in MarkDown, and should be added since mkdocs is now available in Fedora.

%install
%pyproject_install
%pyproject_save_files -l pydantic


%check
%pyproject_check_import -e pydantic.mypy -e pydantic.v1.mypy
%if %{with tests}
# We don't build docs or care about benchmarking
ignore="${ignore-} --ignore=tests/test_docs.py"
ignore="${ignore-} --ignore=tests/benchmarks"

# Upstream Python 3.14 support is not done yet. These are the remaining test
# failures:
k="${k-}${k+ and} not test_annotated_optional_field"
k="${k-}${k+ and} not test_annotated_with_field_default_factory"
k="${k-}${k+ and} not test_annotation_with_double_override"
k="${k-}${k+ and} not test_annotations_valid_for_field_inheritance_with_existing_field"
k="${k-}${k+ and} not test_callable_json_schema_extra_dataclass"
k="${k-}${k+ and} not test_create_model_must_not_reset_parent_namespace"
k="${k-}${k+ and} not test_cross_module_cyclic_reference_dataclass"
k="${k-}${k+ and} not test_dataclass_alias_generator"
k="${k-}${k+ and} not test_dataclass_docs_extraction"
k="${k-}${k+ and} not test_default_factory_field[Field]"
k="${k-}${k+ and} not test_field_title_generator_in_dataclass_fields"
k="${k-}${k+ and} not test_forward_ref_auto_update_no_model"
k="${k-}${k+ and} not test_forward_ref_one_of_fields_not_defined"
k="${k-}${k+ and} not test_incomplete_superclass"
k="${k-}${k+ and} not test_init_false_not_in_signature"
k="${k-}${k+ and} not test_init_false_with_default"
k="${k-}${k+ and} not test_init_false_with_post_init"
k="${k-}${k+ and} not test_init_var_field"
k="${k-}${k+ and} not test_kw_only_subclass"
k="${k-}${k+ and} not test_model_rebuild_localns"
k="${k-}${k+ and} not test_pickle_dataclass_nested_in_model[NonImportableNestedDataclassModel-True]"
k="${k-}${k+ and} not test_pickle_model[NonImportableModel-True]"
k="${k-}${k+ and} not test_pickle_nested_model[NonImportableNestedModel-True]"
k="${k-}${k+ and} not test_rebuild_dataclass"
k="${k-}${k+ and} not test_repr_false[Field]"
k="${k-}${k+ and} not test_root_validator"
k="${k-}${k+ and} not test_schema"
k="${k-}${k+ and} not test_signature"
k="${k-}${k+ and} not test_top_level_fwd_ref"
k="${k-}${k+ and} not test_undefined_types_warning_1a_raised_by_default_2a_future_annotations"

%pytest ${ignore-} -k "${k-}" -rs
%endif


%files -n python3-pydantic -f %{pyproject_files}
%doc CITATION.cff
%doc HISTORY.md
%doc README.md

# Note that the timezone extra has no dependencies on our platform.
%pyproject_extras_subpkg email timezone -n python3-pydantic

%files doc
%license LICENSE
%doc docs/*

%changelog
## START: Generated by rpmautospec
* Sat Jun 21 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 2.11.7^20250615git0c4a22b-1
- Update to a snapshot that mostly supports Python 3.14
- Fixes RHBZ#2372054

* Mon Jun 16 2025 Susi Lehtola <jussilehtola@fedoraproject.org> - 2.11.5-2
- Bump to build with Python 3.14 in rawhide

* Fri May 23 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 2.11.5-1
- Update to 2.11.5 (close RHBZ#2368150)

* Mon May 05 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 2.11.4-1
- Update to 2.11.4 (close RHBZ#2363016)

* Mon Apr 14 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 2.11.3-3
- Better document test dependencies
- Drop no-longer-necessary BuildRequires on python3-rich

* Mon Apr 14 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 2.11.3-2
- Remove conditionals etc. for F42 and older

* Mon Apr 14 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 2.11.3-1
- Update to 2.11.3 (close RHBZ#2355554)

* Mon Apr 14 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 2.10.6-2
- Fix generation of dependencies for extras

* Fri Jan 24 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 2.10.6-1
- Update to 2.10.6 (close RHBZ#2341876)

* Thu Jan 16 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 2.10.5-1
- Update to 2.10.5 (close RHBZ#2337015)

* Fri Jan 10 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 2.10.4-2
- Do the same test skips from F40 in EPEL10, too

* Wed Dec 18 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.10.4-1
- Update to 2.10.4 (close RHBZ#2333060)

* Fri Dec 06 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.10.3-1
- Update to 2.10.3 (close RHBZ#2330186)

* Tue Nov 26 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.10.2-1
- Update to 2.10.2 (close RHBZ#2328974)

* Sun Nov 24 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.10.1-1
- Update to 2.10.1 (close RHBZ#2327740)

* Fri Oct 11 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.9.2-2
- Confirm that the license is SPDX MIT

* Wed Sep 18 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.9.2-1
- Update to 2.9.2

* Wed Sep 11 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.9.1-1
- Update to 2.9.1 (close RHBZ#2310330)

* Fri Aug 16 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.8.2-4
- Add pytz to test dependencies

* Fri Aug 02 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.8.2-3
- Re-enable a test that required pytest 8, now in F41

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.8.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Sun Jul 07 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.8.2-1
- Update to 2.8.2 (close RHBZ#2295692)

* Sat Jun 29 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.8.0~b1-1
- Update to 2.8.0~b1

* Tue Jun 18 2024 Python Maint <python-maint@redhat.com> - 2.7.4-3
- Rebuilt for Python 3.13

* Fri Jun 14 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.7.4-1
- Update to 2.7.4 (close RHBZ#2292385)

* Sun Jun 09 2024 Python Maint <python-maint@redhat.com> - 2.7.3-2
- Rebuilt for Python 3.13

* Wed Jun 05 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.7.3-1
- Update to 2.7.3 (close RHBZ#2290381)

* Thu May 30 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.7.2-2
- Ignore a new DeprecationWarning from Python 3.13 for now

* Wed May 29 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.7.2-1
- Update to 2.7.2 (close RHBZ#2283727)

* Wed Apr 24 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.7.1-1
- Update to 2.7.1. Fixes rhbz#2276773.

* Sat Apr 13 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.7.0-1
- Update to 2.7.0. Fixes rhbz#2274645.
- Package HISTORY.md and the new CITATION.cff as documentation.
- Move large documentation to a -doc subpackage

* Mon Mar 18 2024 Maxwell G <maxwell@gtmx.me> - 2.6.4-1
- Update to 2.6.4. Fixes rhbz#2269288.

* Wed Feb 28 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.6.3-1
- Update to 2.6.3. Fixes rhbz#2266533.

* Sat Feb 24 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.6.2-1
- Update to 2.6.2. Fixes rhbz#2265749.

* Mon Feb 05 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.6.1-1
- Update to 2.6.1. Fixes rhbz#2261885.

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Dec 24 2023 Maxwell G <maxwell@gtmx.me> - 2.5.3-1
- Update to 2.5.3. Fixes rhbz#2255709.

* Sat Nov 25 2023 Maxwell G <maxwell@gtmx.me> - 2.5.2-1
- Update to 2.5.2. Fixes rhbz#2157134.

* Fri Nov 10 2023 Maxwell G <maxwell@gtmx.me> - 2.4.2-1
- Update to 2.4.2. Fixes rhbz#2157134.
- Obsolete dotenv extra that was removed upstream.

* Tue Oct 10 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.10.13-1
- Update to 1.10.13.

* Sat Aug 12 2023 Maxwell G <maxwell@gtmx.me> - 1.10.12-1
- Update to 1.10.12.

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.10.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Jun 15 2023 Python Maint <python-maint@redhat.com> - 1.10.2-3
- Rebuilt for Python 3.12

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.10.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Wed Sep 07 2022 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.10.2-1
- Update to 1.10.2.

* Thu Sep 01 2022 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.10.1-1
- Update to 1.10.1.

* Wed Aug 24 2022 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.9.2-1
- Update to 1.9.2.

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.9.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jun 13 2022 Python Maint <python-maint@redhat.com> - 1.9.1-2
- Rebuilt for Python 3.11

* Thu Jun 09 2022 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.9.1-1
- Update to 1.9.1.

* Wed Feb 02 2022 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.9.0-1
- Update to 1.9.0.

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Dec 22 2021 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.8.2-1
- Update to 1.8.2.

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 1.7.4-2
- Rebuilt for Python 3.10

* Tue May 11 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 1.7.4-1
- Update to 1.7.4; fixes CVE-2021-29510

* Wed Feb 24 2021 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.7.3-1
- Update to 1.7.3.

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Aug 11 2020 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.6.1-1
- Update to 1.6.1.

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.3-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 1.3-5
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Jan 07 2020 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.3-3
- python-email_validator is now packaged as python-email-validator...

* Tue Jan 07 2020 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.3-2
- Review fixes.

* Mon Jan 06 2020 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.3-1
- Update to 1.3.
- Review fixes.

* Sun Nov 24 2019 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.1.1-1
- Update to 1.1.1.

* Sat Jul 27 2019 Susi Lehtola <jussilehtola@fedoraproject.org> - 0.31-1
- Initial package.

## END: Generated by rpmautospec
